package de.intevation.artifacts;

import org.w3c.dom.Document;

import java.io.OutputStream;
import java.io.IOException;

/**
 * Interface of an artifact managing database.
 *
 * @author Sascha L. Teichmann (sascha.teichmann@intevation.de)
 */
public interface ArtifactDatabase
{
    public interface DeferredOutput {

        void write(OutputStream output) throws IOException;

    } // interface DeferredOut

    /**
     * List of artifact factories names accessible through the database.
     * @return pairs of names and descriptions of the factories.
     */
    String [][] artifactFactoryNamesAndDescriptions();

    Document createArtifactWithFactory(String factory)
        throws ArtifactDatabaseException;

    Document describe(String artifact)
        throws ArtifactDatabaseException;

    Document advance(String artifact, Document target)
        throws ArtifactDatabaseException;

    Document feed(String artifact, Document data)
        throws ArtifactDatabaseException;

    DeferredOutput out(String artifact, Document format)
        throws ArtifactDatabaseException;

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
